(()=>{"use strict";var e={744:(e,t)=>{t.Z=(e,t)=>{const n=e.__vccOpts||e;for(const[e,r]of t)n[e]=r;return n}}},t={};function n(r){var o=t[r];if(void 0!==o)return o.exports;var l=t[r]={exports:{}};return e[r](l,l.exports,n),l.exports}(()=>{const e=Vue;var t={class:"flex justify-center items-center"},r={class:"w-full"},o=(0,e.createElementVNode)("p",{class:"leading-tight mt-3"}," Hier können Sie die dynamischen Inhalte Ihrer Website selbständig verwalten. ",-1),l={class:"md:grid md:grid-cols-2"},a={class:"border-r border-b border-gray-200 dark:border-gray-700"},c=["href"];var i={class:"flex p-6"},s={class:"leading-normal mt-3"};const d={name:"DashboardElement",props:{title:String,text:String}};var m=n(744);const u={name:"Dashboard",props:{card:Object},components:{DashboardElement:(0,m.Z)(d,[["render",function(t,n,r,o,l,a){var c=this,d=(0,e.resolveComponent)("Heading");return(0,e.openBlock)(),(0,e.createElementBlock)("div",i,[(0,e.createElementVNode)("div",null,[(0,e.createVNode)(d,{level:3},{default:(0,e.withCtx)((function(){return[(0,e.createTextVNode)((0,e.toDisplayString)(c.title),1)]})),_:1}),(0,e.createElementVNode)("p",s,(0,e.toDisplayString)(this.text),1)])])}]])},methods:{link:function(e){return"/nova/resources/".concat(e)}}},p=(0,m.Z)(u,[["render",function(n,i,s,d,m,u){var p=this,v=(0,e.resolveComponent)("Heading"),f=(0,e.resolveComponent)("DashboardElement"),k=(0,e.resolveComponent)("Card");return(0,e.openBlock)(),(0,e.createElementBlock)("div",t,[(0,e.createElementVNode)("div",r,[(0,e.createVNode)(v,null,{default:(0,e.withCtx)((function(){return[(0,e.createTextVNode)("Herzlich Willkommen")]})),_:1}),o,(0,e.createVNode)(k,{class:"mt-8"},{default:(0,e.withCtx)((function(){return[(0,e.createElementVNode)("div",l,[((0,e.openBlock)(!0),(0,e.createElementBlock)(e.Fragment,null,(0,e.renderList)(p.card.elements,(function(t){return(0,e.openBlock)(),(0,e.createElementBlock)("div",a,[t.link?((0,e.openBlock)(),(0,e.createElementBlock)("a",{key:0,href:u.link(t.link),class:"no-underline"},[(0,e.createVNode)(f,{title:t.title,text:t.text},null,8,["title","text"])],8,c)):((0,e.openBlock)(),(0,e.createBlock)(f,{key:1,title:t.title,text:t.text},null,8,["title","text"]))])})),256))])]})),_:1})])])}]]);Nova.booting((function(e,t){e.component("dashboard",p)}))})()})();