<?php

return [
    'elements' => [
        [
            'title' => 'Suche',
            'text' => 'Hier können Sie Begriffe eingeben, um nach Navigationspunkten oder Inhalten zu suchen.',
            'link' => null,
        ],
        [
            'title' => 'Ressourcen',
            'text' => 'Unter Ressourcen finden Sie die User-Verwaltung und die Bearbeitungsfunktionen für die editierbaren Bereiche Ihrer Website.',
            'link' => null,
        ],
    ],
];
