let mix = require('laravel-mix')

require('./nova.mix')

mix.disableNotifications()
    .setPublicPath('dist')
    .js('resources/js/dashboard.js', 'js')
    .vue({ version: 3 })
    .nova('tricks/dashboard')
    .disableNotifications()
